function [Iout, vmin, vmax] = simplestColorBalance (Iin, w_clip, k_clip)
% simplestColorBalance scales the intensities of an image so that a certain
% and provided proportion of pixels are clipped.
% 
% [Iout, vmin, vmax] = simplestColorBalance (Iin, w_clip, k_clip)
%
% Input image must belong to [0,1]
% w_clip and k_clip too.
%
% See "ipolSCB" for the Simplest Color Balance closer to the original.
% See "SimplestColorBalance" for the original version of this function.
%
% Created on Tuesday, April 10, 2018.
% Charles Hessel, CMLA, ENS Paris-Saclay

%%% find max and min values with appropriate clipping proportions
[H,X] = histcounts(Iin(:),1024);
gap   = (max(Iin(:))-min(Iin(:)))/2048;
X = X(1:end-1)+gap;
histocum = cumsum(H(:));
N        = numel(Iin);
imax     = find(histocum >= ceil((1-w_clip)*N),1);
imin     = find(histocum > floor((0+k_clip)*N),1);
if imin~=1, imin=imin-1; end
vmax     = X(imax) + gap;
vmin     = X(imin) - gap;

%%% scale image
Iout     = (Iin-vmin)/(vmax - vmin);

%%% print what's going to be done
fprintf('--- Normalization with clipping:\n');
fprintf('Pixels clipped to white: %2.3f %%\n', 100*sum(Iout(:) > 1)/N);
fprintf('Pixels clipped to black: %2.3f %%\n', 100*sum(Iout(:) < 0)/N);
if vmin<0
    fprintf('=> Iout = (Iin+%.3f)/%.3f\n',-vmin,vmax-vmin);
else
      fprintf('=> Iout = (Iin-%.3f)/%.3f\n',vmin,vmax-vmin);  
end
fprintf('--------------------------------\n');

%%% clip image
Iout(Iout > 1) = 1;
Iout(Iout < 0) = 0;